Header

Struct Header 

pub struct Header {
    pub text: String,
    pub level: HeaderLevel,
}
A markdown header.

Fields

text: String

The header text.

level: HeaderLevel

The header level.

Implementations

Source

impl Header

pub fn new() -> Self

Creates a new empty header with a level of 1.

pub fn from(text: impl Into<String>, level: impl Into<HeaderLevel>) -> Self

Creates a new header.

Panics

Panics if the header level is not valid (one to six inclusive).